| Title: | buildr |
|---|---|
| Description: | Simple package build server. |
| Authors: | Rich FitzJohn |
| Maintainer: | Rich FitzJohn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.3 |
| Built: | 2026-06-01 07:43:20 UTC |
| Source: | https://github.com/mrc-ide/buildr |
Build a set of binaries, waiting until complete
build_binaries(filenames, host, port = 8765, ..., dest = tempfile())build_binaries(filenames, host, port = 8765, ..., dest = tempfile())
filenames |
Vector of filenames of the source packages |
host |
A hostname for the build server, or |
port |
Port number for the build server |
... |
Arguments passed through to the |
A character vector of filenames
Client for submitting and retrieving packages from a buildr server.
buildr_client(host, port = 8765) buildr_available(host, port = 8765)buildr_client(host, port = 8765) buildr_available(host, port = 8765)
host |
Hostname that the buildr server is running on |
port |
Port that the buildr server is running on (the default here matches the buildr server default) |